---
title: Cybrecluster
---

The Cybrecluster project aims at linking my different websites in a manner
akin to a webring. It was imagined during the summer of 2020.

## Sites

* https://brainshit.fr/
* https://tilde.town/~lucidiot/
* https://envs.net/~lucidiot/
* ~https://breadpunk.club/\~lucitoast/~

## Goals

* Increase the visibility of all of my projects
* Lighten the load on [mountain](../mountain.html) by trusting other tildes
* Increase my involvement in tildes
* Encourage both a visitor and me to browse all of my websites
* Reduce my fear of abandoning a particular website

## My computers are my tools

When I designed this project, my French blog was hosted at home on `carthage`,
an Intel NUC, using Ubuntu Server, Docker, systemd, Apache, PHP, MySQL, and
the server was also providing other services such as Nextcloud, HedgeDoc,
TinyTinyRSS, a NuGet package server, and a LAN-only WebDAV server, all behind
a nginx reverse proxy with a separate container to handle Let's Encrypt
certificate renewal.  All of those containers were managed using Docker
Compose.

Handling this structure was pretty complex, as I get very quickly frustrated
when it comes to most modern deployment tech.  I realized over time that this
is not what I want to do.  I do not want the "Cloud".  If I am going to
self-host, then it should be by my rule, by how I think computers should run.
Feeling constantly annoyed at my own server's setup, feeling unable to make any
process on a project that relates to this server because of its state, just
means I need to change the way I run my server.

I like the tilde culture, in which we turn random, "soulless" computers in the
cloud into cozy places.  Into safe places where I feel like I can grow, I can
thrive.  So I wanted to have a server that gets closer to that.

I still want to self-host; I like being able to see my equipment just by
turning my head, having access to it even when my internet connection is down,
or hearing a very quiet fan noise at night.  But I also want to get involved
in tildes, and I have an account on three tildes already; I want to publish
everywhere and not look dead.  I was putting some stress on myself because I
really wanted to do something, I do not want those accounts to be a waste.
The last thing I want to do to any tilde is to make it waste resources.

I solved that dilemma, and started seeing my server in a better light, by
imagining the cybrecluster.

## Rules

After getting a little further into this idea, making it clearer in my mind,
I defined a set of rules.

* **Be simple.**
  * Start small
  * Plan often, but plan small
  * Remove unneeded abstractions
* **Be resilient.**
  * Backups
  * Write documentation for my projects
  * Reuse existing systems, formats and protocols
  * [Archive](https://archive.org) things
  * Monitor my server, sites, services
* **Be active.**
  * Learn what I need, not just for the sake of learning
  * Create what I want, what I enjoy
  * Publish what I can

This sounds rather close to an [integrity report](../integrity-report.html).

## Actions taken

* Stopped the NuGet package server as the projects that relied on it went stale
* Migrated to envs.net's TinyTinyRSS instance
* Stopped my TinyTinyRSS instance
* Stopped the PostgreSQL database that powered the TinyTinyRSS instance
* Migrated my files from Nextcloud to Syncthing
* Migrated my calendar and contacts to [Framagenda](https://framagenda.org)
* Stopped my Nextcloud instance
* Migrated my HedgeDoc files to some .md files in a Syncthing folder, using
  envs.net's HedgeDoc instance when I need multiplayer text editing
* Stopped my HedgeDoc instance
* Set up Alpine Linux, nginx, certbot, MariaDB, PHP 7, Munin and Syncthing on
  [Mountain](../mountain.html)
* Migrated my WebDAV server to Mountain
* Migrated my French blog to PHP 7
* Migrated my French blog to Mountain
* Stopped all Docker services on Carthage
* Migrated all my Syncthing folders to Mountain
* [Sold Carthage](./carthage.html) to a friend at a fair price
* Added a Cybrecluster banner to all of my websites
* Started posting about my tilde projects on my self-hosted French blog
* Created this wiki
* Added a Gopher version of this wiki

## Actions to take

[This blog article](https://brainshit.fr/read/240) introduces the cybrecluster
to my French audience and describes the actions to take regarding
[Brainshit](../brainshit.html).

* Create a "decentralized monitoring": each server (mine, or a tilde) checks
  on the others, and reports their status on a status page
  * Could have an RSS feed with [mod_servicestatus][mod_servicestatus]
  * Could have a cool diagram ([source](./graph.dot)):  
    ![cool graph](./graph.png)
* Maybe self-host a [DAViCal](https://davical.org) instance, as Framagenda's
  operator, Framasoft, encourages moving away from its platform into smaller,
  more decentralized hosts
* Make my French blog into a static site
* Remove PHP 7 and MariaDB from Mountain
* Convert the tilde.town site to a static site generator
* Add a Gopher version of my french blog
* Add a Gopher version of my town site
* ~~Add a Gopher version of my breadsite~~

[mod_servicestatus]: https://web.resource.org/rss/1.0/modules/servicestatus/
