---
title: About the wiki
---

## Why?

There has been a recent trend to set up [[zettelkasten]]s, which got me to
look around and see how other people handled their knowledge using a wiki.
Personal wiki articles are often short, and the focus is more on browsing
around and discovering new links between ideas.

Going public-first instead of private-first is also a trend, with wikis on
Git repos or special websites like Andy Matuschak's [[evergreen]] notes.
Going public encourages curiosity, invites others to notice what you want
to learn on or what you know and give you their input, and inspires others.
It feels less like a waste of time.

I initially started a private wiki using Vimwiki, as I just needed a space
to store random ideas and notes and wanted something I felt more in control
of than something like HedgeDoc or CryptPad, and something that I could edit
with a proper text editor and not a web browser.

I decided to move to a public wiki for various reasons:

* Some pages in my private wiki were worthy of being published, but did not
  really fit as blog posts on my french blog or on my other sites.
* Most pages did not fit as blog posts because a blog post gives the feel of
  something becoming permanent, becoming something you cannot go back to edit
  on.  Posting a journal of sorts about your research on a topic to circumvent
  this issue just makes it much harder for someone to read your results, as
  they need to read through the entire archive.
* Publishing online makes it feel, for me, that an idea I have, a thought,
  anything I write will not be lost.
* Publishing makes my writing more worth it than just writing for myself.
* All the arguments mentioned in other personal wikis, blog articles about
  personal wikis, research about personal knowledge management, blog articles
  about blogging, etc., all apply here too.

## Links

* <https://github.com/chrisman/knowledge/wiki>
* <https://wiki.nikitavoloboev.xyz/>
* <https://wiki.nikitavoloboev.xyz/other/wiki-workflow#similar-wikis-i-liked>
* <https://notes.andymatuschak.org/About_these_notes>
* <https://mitpress.mit.edu/books/science-managing-our-digital-stuff>
* <https://sive.rs/dj>
* <https://joelhooks.com/digital-garden>
* <https://stackingthebricks.com/how-blogs-broke-the-web/>

## Software choice

Wikis that use relational databases or non-human-editable formats go against
my new ethics on web services: the most static possible, and the less risky
if [[mountain]] goes down, even if i do not set up anything for backups.

Wikis that would be to annoying to use (not available on every device, not
available offline, …) would make me give up earlier, so the choice of
software is pretty crucial I want to keep up this practice.

What follows is probably pretty harsh, biased, and not well thought-out enough,
and that's just how most of my software decisions go anyway :D

Paper
: Basically a Zettelkasten.
  I would not have access to it on the go, would not be able to search quickly,
  and would not be able to publish easily, but I would definitely not have the
  UX or modern tech issues I have with everything else.

Vimwiki
: Does not use Markdown by default, but well integrated with Vim.  I tried it
  out for a bit and I actually do not use most of it, so I found out I was just
  fine with regular Markdown.

TiddlyWiki
: I had tried it for a fiction writing project, to describe the entire lore
  a la Wikia.  The UI is far from being uniform since everything is a plugin,
  and it is pretty resource-heavy and requires Node.js; the software does not
  easily get out of your way for you to just focus on writing.

Org-mode
: I have yet to find something that cannot be structured using Org-mode, and
  there are many Org-mode-based software out there, but having to learn Emacs
  implies that I will very quickly give up on that.

MediaWiki
: Definitely not text-file-based, can be pretty heavy to host compared to all
  my sites.  Promotes long-form writing when most personal wikis tend to have
  shorter articles and more links, similarly to a Zettelkasten.

[Weewiki](https://pbat.ch/wiki/weewiki/)
: Interesting, and it uses literate programming which I like, but it still
  uses Org-mode and a binary format.

[Obsidian](https://obsidian.md/)
: Proprietary, paid, and it looks like the UIs you get from Electron apps
  so I expect it to be too resource-heavy.

[Zettelkasten](http://zettelkasten.danielluedecke.de/) (the software, not the method)
: Uses Java and seems to use its own format, not just regular text files.

[Neuron](https://neuron.zettel.page/)
: Interesting, but felt too complex at the time I started this wiki for what
  I expected to need.

[Dendron](https://wiki.dendron.so/)
: Hierarchical, while what got me more interested in a system such as the
  Zettelkasten was the ability to spawn relationships between random unrelated
  items (which would not be hierachically related at all).  Also requires
  Visual Studio Code, which means it will be resource-heavy.

## Goals

I am currently moving most of my private Vimwiki-based wiki into this public
wiki or into other places such as my notebooks, my archives, or other sites
on the cybrecluster.

I want to try to use this wiki more as a tool for research than as yet another
place to publish things, and instead publish the completed research on my
French blog, as I did for the [Chinese date parsing](./cn-date.html) for
example.

I am reading *How to Take Smart Notes* by Sönke Ahrens, a book that introduces
to the Zettelkasten, and am now considering adding a "reference" folder in this
wiki for various blog articles, books, etc. that I might stumble upon and find
interesting thoughts on, to reproduce the reference system mentioned in that
book.  One blog post, for which I had written an incomplete two thousand word
draft, then gave up on it, could benefit from that.

## Implementation notes

This wiki has an [everything](./everything.html) page that gets generated from
the XML output mode of the `tree` command.  I wrote an XSD for it to better
document the format: [tree XSD](./xsd/tree.xsd)
